@@ -37,7 +37,7 @@ print "ok 2\n";
    $handler->{'Pretty'}{'CatchWhiteSpace'}=0;
    $handler->{'Pretty'}{'NoWhiteSpace'}=1;
    $handler->{'Pretty'}{'NoComments'}=1;
-   $handler->{'Pretty'}{'AddHiddenNewLine'}=1;
+   $handler->{'Pretty'}{'AddHiddenNewline'}=1;
    $handler->{'Pretty'}{'AddHiddenAttrTab'}=1;
    $parser->parse( 'Source' => { 'SystemId' => 'linux.1.xml' } );
    $xml_file->close();
@@ -48,7 +48,7 @@ print "ok 3\n";
    $handler->{'Pretty'}{'CatchWhiteSpace'}=0;
    $handler->{'Pretty'}{'NoWhiteSpace'}=0;
    $handler->{'Pretty'}{'NoComments'}=0;
-   $handler->{'Pretty'}{'AddHiddenNewLine'}=0;
+   $handler->{'Pretty'}{'AddHiddenNewline'}=0;
    $handler->{'Pretty'}{'AddHiddenAttrTab'}=0;
    $handler->{'Pretty'}{'PrettyWhiteNewline'}=1;
    $handler->{'Pretty'}{'PrettyWhiteIndent'}=1;
